* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [SAP Cloud ALM Integration for SAP Discovery](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm)
  * Enabling Discovered Flows
